==> mriqc-24.0.0rc6.tar.gz: mriqc-24.0.0rc6/.maint/CONTRIBUTORS.md <==
# CONTRIBUTORS

This document lists those who have made contributions to the Project.
As per the contributor guidelines, they should be included by default in any publications derived from the Project.

If you are new to the project, don't forget to add your name and affiliation to the list of contributors here! Our Welcome Bot will send an automated message reminding this to first-time contributors.
Before every release, unlisted contributors will be invited again to add their names to this file (just in case they missed the automated message from our Welcome Bot).

| **Lastname** | **Name** | **Handle** | **ORCID** | **Affiliation** |
| --- | --- | --- | --- | --- |
| Achtzehn | Johannes | @jAchtzehn | 0000-0002-0657-6516 | Charité Berlin, Berlin, Germany |
| Baratz | Zvi | @ZviBaratz | 0000-0001-7159-1387 | Sagol School of Neuroscience, Tel-Aviv University |
| Beliy | Nikita | @nbeliy | | CRC ULiege, Liege, Belgium |
| Birman | Daniel | @dbirman | 0000-0003-3748-6289 | Department of Psychology, Stanford University, CA, USA |
| Blair | Ross W. | @rwblair | 0000-0003-3007-1056 | Department of Psychology, Stanford University, CA, USA |
| Chen | Yibei | @yibeichan | 0000-0003-2882-0900 | McGovern Institute for Brain Research, Massachusetts Institute of Technology, Cambridge, USA |
| Clark | Michael G. | @mgclark | | National Institutes of Health, USA |
| Dayan | Michael | @neurorepro | 0000-0002-2666-0969 | International Committee of the Red Cross - ICRC, Geneva, Switzerland |
| Durnez | Joke | @jokedurnez | 0000-0001-9030-2202 | Department of Psychology, Stanford University, CA, USA |
| Erramuzpe | Asier | @erramuzpe | 0000-0002-9402-2184 | Computational Neuroimaging Lab, BioCruces Health Research Institute |
| Fauber | Bennet | @justbennet | | University of Michigan, Ann Arbor, USA |
| Garcia-Dias | Rafael | @garciadias | 0000-0001-9332-1580 | Institute of Psychiatry, Psychology & Neuroscience, King's College London, London, UK |
| Ghosh | Satrajit S. | @satra | 0000-0002-5312-6729 | McGovern Institute for Brain Research, MIT, MA, USA; and Department of Otolaryngology, Harvard Medical School, MA, USA |
| Gomez | Teresa | @teresamg | | The University of Washington eScience Institute, WA, USA |
| Goncalves | Mathias | @mgxd | 0000-0002-7252-7771 | Department of Psychology, Stanford University, CA, USA |
| Halchenko | Yaroslav O. | @yarikoptic | 0000-0003-3456-2493 | Psychological and Brain Sciences Department, Dartmouth College, NH, USA |
| Huffman | Adam | @verdurin | | Department of Physics, Imperial College London, London, UK |
| Kay | Benjamin | @benkay86 | | Washington University School of Medicine, St.Louis, MO, USA |
| Kent | James D. | @jdkent | 0000-0002-4892-2659 | Department of Psychology, University of Texas at Austin, TX, USA |
| Krause | Michael | @octomike | | Max Planck Institute for Human Development, Berlin, Germany |
| Lee | John A. | @leej3 | 0000-0001-5884-4247 | Quansight, Dublin, Ireland |
| Nichols | Thomas | @nicholst | 0000-0002-4516-5103 | Oxford Big Data Institute, University of Oxford, Oxford, GB |
| Nielson | Dylan | @Shotgunosine | 0000-0003-4613-6643 | Section on Clinical and Computational Psychiatry, National Institute of Mental Health, Bethesda, MD, USA |
| Papadopoulos Orfanos | Dimitri | @DimitriPapadopoulos | 0000-0002-1242-8990 | NeuroSpin, CEA, Université Paris-Saclay, NeuroSpin, Gif-sur-Yvette, France |
| Raikes | Adam C. | @araikes | | Center for Innovation in Brain Science, University of Arizona, Tucson, AZ, USA |
| Rokem | Ariel | @arokem | 0000-0003-0679-1985 | The University of Washington eScience Institute, WA, USA |
| Sadil | Patrick | @psadil | 0000-0003-4141-1343 | Johns Hopkins Bloomberg School of Public Health, MD, USA |
| Salo | Taylor | @tsalo | 0000-0001-9813-3167 | Department of Psychology, Florida International University, FL, USA |
| Savary | Elodie | @esavary | 0000-0002-3896-6906 | Department of Radiology, Lausanne University Hospital and University of Lausanne, Switzerland |
| Tooley | Ursula A. | @utooley | 0000-0001-6377-3885 | Department of Neuroscience, University of Pennsylvania, PA, USA |
| Triplett | William | @wtriplett | 0000-0002-9546-1306 | University of Florida: Gainesville, Florida, US |
| Varada | Jan | @jvarada | | Functional MRI Facility, National Institute of Mental Health, Bethesda, MD, USA |
| Velasco | Pablo | @pvelasco | 0000-0002-5749-6049 | Center for Brain Imaging, New York University, NY, USA |

==> mriqc-24.0.1.tar.gz: mriqc-24.0.1/.maint/CONTRIBUTORS.md <==
# CONTRIBUTORS

This document lists those who have made contributions to the Project.
As per the contributor guidelines, they should be included by default in any publications derived from the Project.

If you are new to the project, don't forget to add your name and affiliation to the list of contributors here! Our Welcome Bot will send an automated message reminding this to first-time contributors.
Before every release, unlisted contributors will be invited again to add their names to this file (just in case they missed the automated message from our Welcome Bot).

| **Lastname** | **Name** | **Handle** | **ORCID** | **Affiliation** |
| --- | --- | --- | --- | --- |
| Achtzehn | Johannes | @jAchtzehn | 0000-0002-0657-6516 | Charité Berlin, Berlin, Germany |
| Baratz | Zvi | @zvi-quantivly | 0000-0001-7159-1387 | Quantivly Inc., Somerville, MA, USA |
| Beliy | Nikita | @nbeliy | | CRC ULiege, Liege, Belgium |
| Birman | Daniel | @dbirman | 0000-0003-3748-6289 | Department of Psychology, Stanford University, CA, USA |
| Blair | Ross W. | @rwblair | 0000-0003-3007-1056 | Department of Psychology, Stanford University, CA, USA |
| Chen | Yibei | @yibeichan | 0000-0003-2882-0900 | McGovern Institute for Brain Research, Massachusetts Institute of Technology, Cambridge, USA |
| Clark | Michael G. | @mgclark | | National Institutes of Health, USA |
| Dayan | Michael | @neurorepro | 0000-0002-2666-0969 | International Committee of the Red Cross - ICRC, Geneva, Switzerland |
| Durnez | Joke | @jokedurnez | 0000-0001-9030-2202 | Department of Psychology, Stanford University, CA, USA |
| Erramuzpe | Asier | @erramuzpe | 0000-0002-9402-2184 | Computational Neuroimaging Lab, BioCruces Health Research Institute |
| Fauber | Bennet | @justbennet | | University of Michigan, Ann Arbor, USA |
| Garcia-Dias | Rafael | @garciadias | 0000-0001-9332-1580 | Institute of Psychiatry, Psychology & Neuroscience, King's College London, London, UK |
| Ghosh | Satrajit S. | @satra | 0000-0002-5312-6729 | McGovern Institute for Brain Research, MIT, MA, USA; and Department of Otolaryngology, Harvard Medical School, MA, USA |
| Gomez | Teresa | @teresamg | | The University of Washington eScience Institute, WA, USA |
| Goncalves | Mathias | @mgxd | 0000-0002-7252-7771 | Department of Psychology, Stanford University, CA, USA |
| Halchenko | Yaroslav O. | @yarikoptic | 0000-0003-3456-2493 | Psychological and Brain Sciences Department, Dartmouth College, NH, USA |
| Huffman | Adam | @verdurin | | Department of Physics, Imperial College London, London, UK |
| Kay | Benjamin | @benkay86 | | Washington University School of Medicine, St.Louis, MO, USA |
| Kent | James D. | @jdkent | 0000-0002-4892-2659 | Department of Psychology, University of Texas at Austin, TX, USA |
| Krause | Michael | @octomike | | Max Planck Institute for Human Development, Berlin, Germany |
| Lee | John A. | @leej3 | 0000-0001-5884-4247 | Quansight, Dublin, Ireland |
| Legarreta Gorroño | Jon Haitz | @jhlegarreta | 0000-0002-9661-1396 | Brigham and Women's Hospital, Mass General Brigham, Harvard Medical School, MA, USA |
| Nichols | Thomas | @nicholst | 0000-0002-4516-5103 | Oxford Big Data Institute, University of Oxford, Oxford, GB |
| Nielson | Dylan | @Shotgunosine | 0000-0003-4613-6643 | Section on Clinical and Computational Psychiatry, National Institute of Mental Health, Bethesda, MD, USA |
| Papadopoulos Orfanos | Dimitri | @DimitriPapadopoulos | 0000-0002-1242-8990 | NeuroSpin, CEA, Université Paris-Saclay, NeuroSpin, Gif-sur-Yvette, France |
| Raikes | Adam C. | @araikes | | Center for Innovation in Brain Science, University of Arizona, Tucson, AZ, USA |
| Rokem | Ariel | @arokem | 0000-0003-0679-1985 | The University of Washington eScience Institute, WA, USA |
| Sadil | Patrick | @psadil | 0000-0003-4141-1343 | Johns Hopkins Bloomberg School of Public Health, MD, USA |
| Salo | Taylor | @tsalo | 0000-0001-9813-3167 | Department of Psychology, Florida International University, FL, USA |
| Savary | Elodie | @esavary | 0000-0002-3896-6906 | Department of Radiology, Lausanne University Hospital and University of Lausanne, Switzerland |
| Tooley | Ursula A. | @utooley | 0000-0001-6377-3885 | Department of Neuroscience, University of Pennsylvania, PA, USA |
| Triplett | William | @wtriplett | 0000-0002-9546-1306 | University of Florida: Gainesville, Florida, US |
| Varada | Jan | @jvarada | | Functional MRI Facility, National Institute of Mental Health, Bethesda, MD, USA |
| Velasco | Pablo | @pvelasco | 0000-0002-5749-6049 | Center for Brain Imaging, New York University, NY, USA |
